from optparse import OptionParser
import sys

def parse_options():
    """
    Handle command-line options with optparse.OptionParser.

    Return list of arguments, largely for use in `parse_arguments`.
    """

    # Initialize
    parser = OptionParser(usage="lurl [options]")

    parser.add_option(
        '-p','--prod',
        dest='curl_prod',
        default=None,
        help="put your cURL for production"
    )

    parser.add_option(
       '-s','--stag',
        dest='curl_stag',
        default=None,
        help="put your cURL for staging"
    )

    parser.add_option(
        '--stag-har-folder',
        dest='stag_har_folder',
        default=None,
        help="put your har folder path for staging"
    )

    parser.add_option(
        '--prod-har-folder',
        dest='prod_har_folder',
        default=None,
        help="put your har folder path for production"
    )

    parser.add_option(
       '--skip-response',
        dest='skip_response',
        action='store_true',
        default=False,
        help="skip set response"
    )

    # Finalize
    # Return three-tuple of parser + the output from parse_args (opt obj, args)
    opts, args = parser.parse_args()
    return parser, opts, args


from optparse import OptionParser
import os, sys
from . import tkp_struct, args_parser, multihar
from collections import OrderedDict

def main():
    parser, options, arguments = args_parser.parse_options()
    
    if not options.curl_prod is None or not options.curl_stag is None:
        req = tkp_struct.TkpStruct(options.curl_prod,options.curl_stag)
        req.get_as_tkp()

    if not options.stag_har_folder is None or not options.prod_har_folder is None :
        curls_stag = curls_prod = curls_presenter = OrderedDict()
        if not options.stag_har_folder is None :
            curls_stag = multihar.get_curls(options.stag_har_folder)
            curls_presenter = curls_stag
        if not options.prod_har_folder is None:
            curls_prod = multihar.get_curls(options.prod_har_folder)
            curls_presenter = curls_prod
        for file_id, curl in curls_presenter.items(): 
            curl_prod = curls_prod[file_id] if file_id in curls_prod else None
            curl_stag = curls_stag[file_id] if file_id in curls_stag else None
            req = tkp_struct.TkpStruct(curl_prod=curl_prod, curl_stag=curl_stag, file_id=file_id)
            req.get_as_tkp()
    
    sys.exit(0)

if __name__ == '__main__':
    main()


import os
from Naked.toolshed.shell import muterun_js
from collections import OrderedDict

def get_curls(har_folder_path):
    curl_string_list = get_curl_string_list(har_folder_path)
    curls = OrderedDict()
    for curl_string in curl_string_list :
        curl, file_id = get_curl_and_file_id(curl_string)
        curls[file_id] = curl
    return curls

def get_curl_string_list(har_folder_path):
    response = muterun_js(get_hartocurl_file() + ' "' + har_folder_path + '"')
    curl_string_list = list()
    if response.exitcode == 0:
        curl_string_list = response.stdout.decode('utf-8').splitlines()
    else :
        print(response.stderr)
    return curl_string_list

def get_file_id(path_string):
    file_id = path_string
    try:
        file_id = file_id.rsplit('/',1)[1]
    except:
        pass
    return file_id


def get_curl_and_file_id(response_string):
    response_split = response_string.split("---",1)
    curl_string = response_split[1]
    file_id = get_file_id(response_split[0])
    return curl_string, file_id

def get_hartocurl_file():
    return os.path.join(os.path.abspath(os.path.dirname(__file__)), 'harcurl.js')


import requests
import uncurl
import re
import urllib.parse
import pprint
import json
from .requrl import LurlRequest
import time

class TkpStruct(object):

    def __init__(self, curl_prod=None, curl_stag=None, file_id=None):
        self.request_presenter = None
        if not curl_stag is None :
            self.request_stag = LurlRequest(curl_stag)
            self.request_presenter = self.request_stag
        else :
            self.request_stag = dict()
        if not curl_prod is None :
            self.request_prod = LurlRequest(curl_prod)
            self.request_presenter = self.request_prod
        else :
            self.request_prod = dict()
        self.base = None
        self.file_id = file_id

    def get_as_tkp(self):
        self.construct()
        # pp = pprint.PrettyPrinter(indent=4)
        # pp.pprint(self.base)
        self.print_to_file()

    def print_to_file(self):
        path_split = self.request_presenter.path.split("/")
        path_for_file = path_split[1]
        path_split = path_split[2:]
        for sub_path in path_split :
            path_for_file = path_for_file + sub_path.capitalize()
        if not self.file_id is None:
            path_for_file = path_for_file + "_" + self.file_id
        file_name = "test_SERVICENAME_"+path_for_file+".json"
        f = open(file_name, "w")
        f.write(json.dumps(self.base, indent=4, sort_keys=True))
        f.close()
        print(file_name + " has just created")

    def construct(self) :
        self.construct_base()
        self.base["structure"].append(self.get_production_structure())
        self.base["structure"].append(self.get_staging_structure())

    def construct_base(self) :
        self.base = {
            "queryName": self.get_queryName(),
            "serviceName":"REPLACE_TO_SERVICE_NAME",
            "apiName": self.get_apiName(),
            "testCaseDescription": "call " + self.request_presenter.path,
            "testCasePriority": "P1",
            "httpMethod":self.request_presenter.method,
            "headerMap":self.request_presenter.headers,
            "query":"",
            "filterKeys": [],
            "structure": []
        }

    def get_apiName(self):
        api_name = self.request_presenter.path
        # if len(self.request_presenter.query) > 0 :
        #     get_param_tuple = urllib.parse.parse_qsl(self.request_presenter.query)
        #     get_param_dict = dict()
        #     for field, value in get_param_tuple :
        #         get_param_dict[field] = "{" + field + "}"
        #     api_name = api_name + "?" + "&".join("{}={}".format(*i) for i in get_param_dict.items())
        return api_name
    
    def get_apiParamMap_from_query(self, request):
        query_tuple = urllib.parse.parse_qsl(request.query)
        query_dict = dict((x, y) for x, y in query_tuple)
        return query_dict

    def get_queryName(self):
        query_name = self.request_presenter.method + " : " + self.request_presenter.path
        if not self.file_id is None :
            query_name = query_name + " : " + self.file_id
        return query_name

    def get_variables(self, request):
        if self.request_presenter.method == "GET" :
            return self.get_apiParamMap_from_query(request)
        else :
            return json.loads(request.parsed.data)

    def get_production_structure(self):
        env_name = "production"
        return self.set_structure(env_name, self.request_prod)

    def get_staging_structure(self):
        env_name = "staging"
        return self.set_structure(env_name, self.request_stag)
    
    def set_structure(self, env_name, request) :
        if not bool(request) :
            structure = {
                "env" : env_name,
                "apiParamMap":dict(),
                "variables": dict(),
                "responseString":{},
                "responseCode":0
            } 
        else :
            request.call()
            structure = { 
                "env":env_name,
                "apiParamMap":dict(),
                "variables": self.get_variables(request),
                "responseString":request.response_content,
                "responseCode":request.response.status_code
            }
        return structure








import requests
import uncurl
import re
import urllib.parse
import pprint
import json

class LurlRequest(object):

    def __init__(self, curl):
        self.curl = curl
        self.parsed = uncurl.parse_context(self.curl)
        self.request = uncurl.parse(self.curl)
        self.request_body = self.parsed.data
        self.method = self.parsed.method.upper()
        self.headers = dict(self.parsed.headers)
        self.query = ""
        self.path = ""
        self.parse_url()
        self.response = ""
        self.response_content = ""

    def parse_url(self):
        endpoint = re.findall("^http.*//[^/]*(/.*?)$", self.parsed.url)[0]
        endpoint_split = endpoint.split("?",1)
        self.path = endpoint_split[0]
        if len(endpoint_split) > 1 :
            self.query = endpoint_split[1]
    
    def call(self):
        self.response = eval(self.request)
        self.response_content = self.response.text
        self.try_convert_as_json()
    
    def try_convert_as_json(self):
        try:
            self.response_content = json.loads(self.response.text)
        except:
            pass








# encoding: utf-8

from setuptools import setup, find_packages, Command
import sys
import os
import re
import ast

this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md')) as f:
    long_description = f.read()

setup(
    name='lurl',
    version='0.0.6',
    description='cURL please....',
    # long_description=long_description,
    long_description="convert cURL to another type format!",
    long_description_content_type='text/markdown',
    author='Fernanda Panca Prima',
    author_email='pancaprima8@gmail.com',
    url='',
    license='MIT',
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    packages=find_packages(),
    zip_safe=False,
    install_requires=[
        "requests",
        "puncurl",
        "Naked"
    ],
    entry_points={
        'console_scripts': [
            'lurl = lurl.main:main',
        ]
    },
    include_package_data=True,
    python_requires='>=3.6'
)
